@@ -1,11 +1,10 @@
 #' Descending order
 #'
 #' @description
-#' Arrange in descending order. Can be used inside of `arrange.()`
+#' Arrange in descending order. Can be used inside of `arrange()`
 #'
 #' @param x  Variable to arrange in descending order
 #'
-#' @md
 #' @export
 #'
 #' @examples
@@ -16,7 +15,12 @@
 #' )
 #'
 #' df %>%
-#'   arrange.(c, desc.(a))
-desc. <- function(x) {
+#'   arrange(c, desc(a))
+desc <- function(x) {
   -xtfrm(x)
 }
+
+#' @export
+#' @keywords internal
+#' @inherit desc
+desc. <- desc
