@@ -20,4 +20,7 @@ na_if <- function(x, y) {
 #' @export
 #' @keywords internal
 #' @inherit na_if
-na_if. <- na_if
+na_if. <- function(x, y) {
+  deprecate_dot_fun()
+  na_if(x, y)
+}
