@@ -20,7 +20,7 @@ test_that("works with dot", {
   df <- data.table(x = 1:10)
 
   df <- df %>%
-    filter(between.(x, 1, 4))
+    filter(suppressWarnings(between.(x, 1, 4)))
 
   expect_equal(df$x, 1:4)
 })
