@@ -87,7 +87,8 @@ test_that("can find environment vars in custom functions, #392", {
 test_that("distinct. works", {
   test_df <- tidytable(a = rep(1, 3), b = rep(2, 3), c = c("a", "a", "b"))
   distinct_df <- test_df %>%
-    distinct.()
+    distinct.() %>%
+    suppressWarnings()
 
   expect_equal(names(test_df), names(distinct_df))
   expect_equal(distinct_df$c, c("a", "b"))
