@@ -22,9 +22,10 @@ test_that("works with dot", {
   df <- tidytable(x = c("a", "a", "b"),
                   y = c("a", "a", "b"),
                   z = 1:3)
-  res <- group_by.(df, x, y)
-  expect_equal(group_vars.(res), c("x", "y"))
-  expect_true(is_grouped_df.(res))
+  res <- group_by.(df, x, y) %>%
+    suppressWarnings()
+  expect_equal(suppressWarnings(group_vars.(res)), c("x", "y"))
+  expect_true(suppressWarnings(is_grouped_df.(res)))
 })
 
 test_that("works on rowwise_tt", {
@@ -37,6 +38,7 @@ test_that("ungroup works", {
   df <- tidytable(x = 1:3, y = 1:3) %>%
     group_by(x, y)
   res <- ungroup(df)
+  expect_false(is_grouped_df(res))
   expect_equal(group_vars(res), NULL)
   res <- ungroup(df, y)
   expect_equal(group_vars(res), "x")
