@@ -29,7 +29,7 @@ test_that("follows vctrs recycling rules", {
 
 test_that("na_if. works", {
   vec <- 1:3
-  res <- na_if.(vec, 3)
+  res <- na_if.(vec, 3) %>% suppressWarnings()
   expect_equal(res, c(1, 2, NA))
 })
 
