@@ -7,7 +7,7 @@ test_that("can handle collapsed rows", {
 
 test_that("separate_rows. works", {
   df <- data.table(x = 1:3, y = c("a", "d,e,f", "g,h"))
-  result <- separate_rows.(df, y)
+  result <- separate_rows.(df, y) %>% suppressWarnings()
   expect_equal(result$x, c(1, 2, 2, 2, 3, 3))
   expect_equal(result$y, c("a", "d", "e", "f", "g", "h"))
 })
