@@ -11,7 +11,8 @@ test_that("slice.", {
   test_df <- tidytable(x = c(1,2,3,4), y = c(4,5,6,7), z = c("a", "a", "a", "b"))
 
   sliced_df <- test_df %>%
-    slice.(1:3)
+    slice.(1:3) %>%
+    suppressWarnings()
 
   expect_equal(sliced_df, head(test_df, 3))
 })
